﻿using System.ComponentModel.DataAnnotations;
using Kreta.BusinessLogic.Classes;
using Kreta.BusinessLogic.HelperClasses;
using Kreta.Core;
using Kreta.Enums;
using Kreta.Resources;
using Kreta.Web.Security;

namespace Kreta.Web.Areas.Intezmeny.Models
{
    public class TeremModModel
    {
        public int? TeremId { get; set; }

        public string TeremIDArray { get; set; }

        [Display(Name = nameof(IntezmenyResource.KivalasztottTermek), ResourceType = typeof(IntezmenyResource))]
        public string TeremNevArray { get; set; }

        [Display(Name = nameof(IntezmenyResource.HelyisegNev), ResourceType = typeof(IntezmenyResource))]
        public string Nev { get; set; }

        [Display(Name = nameof(IntezmenyResource.HelyisegJelleg), ResourceType = typeof(IntezmenyResource))]
        public int? Jelleg { get; set; } //TeremTipusEnum

        [Display(Name = nameof(IntezmenyResource.HelyisegJelleg), ResourceType = typeof(IntezmenyResource))]
        public string JellegNev { get { return Jelleg.HasValue ? Jelleg.Value.GetDisplayName<TeremTipusEnum>(ClaimData.SelectedTanevID.Value) : ""; } }

        [Display(Name = nameof(IntezmenyResource.Alapterulet_nm), ResourceType = typeof(IntezmenyResource))]
        [Range(1, 9999, ErrorMessageResourceName = nameof(IntezmenyResource.Alapterulet1Tol9999), ErrorMessageResourceType = typeof(IntezmenyResource))]
        public int? Terulet { get; set; }

        [Display(Name = nameof(IntezmenyResource.Befogadokepesseg), ResourceType = typeof(IntezmenyResource))]
        [Range(0, 5000, ErrorMessageResourceName = nameof(IntezmenyResource.BefogadoKepessegeg0tol5000), ErrorMessageResourceType = typeof(IntezmenyResource))]
        public int? Kapacitas { get; set; }

        [Display(Name = nameof(IntezmenyResource.VizsgaBefogadokepesseg), ResourceType = typeof(IntezmenyResource))]
        [Range(0, 5000, ErrorMessageResourceName = nameof(IntezmenyResource.VizsgaBefogadoKepesseg0Tol5000), ErrorMessageResourceType = typeof(IntezmenyResource))]
        public int? VizsgaKapacitas { get; set; }

        [Display(Name = nameof(IntezmenyResource.Aktiv), ResourceType = typeof(IntezmenyResource))]
        public int? Aktiv { get; set; }

        [Display(Name = nameof(IntezmenyResource.MukodesiHely), ResourceType = typeof(IntezmenyResource))]
        public int? MukodesiHelyID { get; set; }

        [Display(Name = nameof(IntezmenyResource.MukodesiHely), ResourceType = typeof(IntezmenyResource))]
        public string MukodesiHelyNev { get; set; }

        [Display(Name = nameof(IntezmenyResource.Teremfelelos), ResourceType = typeof(IntezmenyResource))]
        public int? Teremfelelos { get; set; }

        [Display(Name = nameof(IntezmenyResource.Teremfelelos), ResourceType = typeof(IntezmenyResource))]
        public string TeremfelelosNev { get; set; }

        [Display(Name = nameof(IntezmenyResource.EgyszerreTobbOratLehetTartani), ResourceType = typeof(IntezmenyResource))]
        public int? TobbOratLehetTartani { get; set; }

        [Display(Name = nameof(IntezmenyResource.WifiElerheto), ResourceType = typeof(IntezmenyResource))]
        public int? WifiLefedett { get; set; }

        [Display(Name = nameof(IntezmenyResource.IsInternetkapcsolatElerheto), ResourceType = typeof(IntezmenyResource))]
        public int? InternetkapcsolatElerheto { get; set; }

        [Display(Name = nameof(IntezmenyResource.TanulokSzamaraHozzaferhInternetesgep), ResourceType = typeof(IntezmenyResource))]
        public int? TanulokSzamaraHozzaferhInternetesgep { get; set; }

        [Display(Name = nameof(IntezmenyResource.PedagogusHozzaferhInternetesgep), ResourceType = typeof(IntezmenyResource))]
        public int? PedagogusHozzaferhInternetesgep { get; set; }

        [Display(Name = nameof(IntezmenyResource.OktCelraHasznaltSzamitogepekSzama), ResourceType = typeof(IntezmenyResource))]
        public int? OktCelraHasznaltSzamitogepekSzama { get; set; }

        [Display(Name = nameof(IntezmenyResource.IsInterakttablavalMunkaallomassalFelszerelt), ResourceType = typeof(IntezmenyResource))]
        public int? InterakttablavalMunkaallomassalFelszerelt { get; set; }

        [Display(Name = nameof(SzervezetResource.Szervezet), ResourceType = typeof(SzervezetResource))]
        public int? ModSzervezetId { get; set; } = null;


        public bool IsFromSzervezet { get; set; }

        public static TeremTobbesModCO ConvertModelToCO(TeremModModel teremModModel)
            => new TeremTobbesModCO()
            {
                ID = teremModModel.TeremId,
                Jelleg = teremModModel.Jelleg,
                Terulet = teremModModel.Terulet,
                Kapacitas = teremModModel.Kapacitas,
                Vizsgakapacitas = teremModModel.VizsgaKapacitas,
                Aktiv = teremModModel.Aktiv,
                MukodesiHelyID = teremModModel.MukodesiHelyID,
                TeremFelelosID = teremModModel.Teremfelelos,
                TobbOratLehetTartani = teremModModel.TobbOratLehetTartani,
                WifiLefedett = teremModModel.WifiLefedett,
                IsInternetkapcsolatElerheto = teremModModel.InternetkapcsolatElerheto,
                TanulokSzamaraHozzaferhInternetesgep = teremModModel.TanulokSzamaraHozzaferhInternetesgep,
                PedagogusHozzaferhInternetesgep = teremModModel.PedagogusHozzaferhInternetesgep,
                OktCelraHasznaltSzamitogepekSzama = teremModModel.OktCelraHasznaltSzamitogepekSzama,
                IsInterakttablavalMunkaallomassalFelszerelt = teremModModel.InterakttablavalMunkaallomassalFelszerelt,
                SzervezetId = teremModModel.ModSzervezetId,
            };

        public static TeremModModel ConvertCOToModel(TeremCO teremCO)
            => new TeremModModel()
            {
                TeremId = teremCO.TeremId,
                Aktiv = teremCO.Aktiv.ToNullableInt(),
                Jelleg = teremCO.Jelleg,
                Kapacitas = teremCO.Kapacitas,
                MukodesiHelyID = teremCO.MukodesiHelyID,
                MukodesiHelyNev = teremCO.MukodesiHelyNev,
                Nev = teremCO.Nev,
                Terulet = teremCO.Terulet,
                TobbOratLehetTartani = teremCO.TobbOratLehetTartani.ToNullableInt(),
                Teremfelelos = teremCO.TeremFelelosID,
                TeremfelelosNev = teremCO.TeremFelelos,
                VizsgaKapacitas = teremCO.Vizsgakapacitas,
                WifiLefedett = teremCO.WifiLefedett.ToNullableInt(),
                InternetkapcsolatElerheto = teremCO.IsInternetkapcsolatElerheto.ToNullableInt(),
                TanulokSzamaraHozzaferhInternetesgep = teremCO.TanulokSzamaraHozzaferhInternetesgep,
                PedagogusHozzaferhInternetesgep = teremCO.PedagogusHozzaferhInternetesgep,
                OktCelraHasznaltSzamitogepekSzama = teremCO.OktCelraHasznaltSzamitogepekSzama,
                InterakttablavalMunkaallomassalFelszerelt = teremCO.IsInterakttablavalMunkaallomassalFelszerelt.ToNullableInt(),
                ModSzervezetId = teremCO.SzervezetId,
            };
    }
}
